==> letsnet-normapi-1.2.3.tgz: package/index.js <==
var mongoose = require('mongoose')
const fs = require('fs')

var API = function(defaults) {
  mongodb = null
  mongooseCredentials = null
  this.openSchema = null
}

API.prototype.mongoConnect = function() {
  if(this.mongooseCredentials == null) throw 'Please set mongooseCredentials with setMongooseCredentials(object) function ...'
  else this.mongodb = mongoose.createConnection('mongodb://' + this.mongooseCredentials.user + ':' + this.mongooseCredentials.passwd + this.mongooseCredentials.url)
}

API.prototype.mongoClose = function() {
  mongoose.disconnect()
  this.mongodb = null
}

API.prototype.setMongooseCredentials = function(object) {
  if(object.user === 'undefined' || object.user == null) throw 'You must define the \'USER\' of the connection!'
  else if(object.url === 'undefined' || object.url == null) throw 'You must define the \'URL\' of the connection!'
  else if(object.passwd === 'undefined' || object.passwd == null) throw 'You must define the \'PASSWORD\' of the connection!'
  else { this.mongooseCredentials = object }
}

API.prototype.closeMongooseCredentials = function(object) {
  this.mongooseCredentials = null
}

API.prototype.createSchema = function(database, object) {
  if(this.mongodb == null) throw 'Please set a connection with mongoConnect function!'
  else this.openSchema = this.mongodb.model(database, new mongoose.Schema(object))
}

API.prototype.closeSchema = function() {
  this.schema = null
}

API.prototype.addFunction = function(defs, rFunction) {
  this[defs.name] = function (defaults, callback) {
    rFunction(defaults)
    .then(function (defaults) {
        defaults.func = defaults.func || `@${defs.name}`
        callback(false, {lCode: defaults.lCode || '-D0', func: defaults.func, msg: defaults.msg || 'Sikeres lefutás!', type: defaults.type || 'success', document: defaults.document || null})
    })
    .catch((defaults) => {
        defaults.func = defaults.func || `@${defs.name}`
        callback(true, {lCode: defaults.lCode || '-D0', func: defaults.func, msg: defaults.msg || 'Hiba a funkció lefutása közben!', type: defaults.type || 'error'})
    })
  }
}

module.exports = API

==> letsnet-normapi-1.2.6.tgz: package/index.js <==
var mongoose = require('mongoose')
const fs = require('fs')
var Queue = require('./queue')

var API = function(defaults) {
  mongodb = null
  mongooseCredentials = null
  this.openSchema = null
  
  queue = null
}

API.prototype.mongoConnect = function() {
  if(this.mongooseCredentials == null) throw 'Please set mongooseCredentials with setMongooseCredentials(object) function ...'
  else this.mongodb = mongoose.createConnection('mongodb://' + this.mongooseCredentials.user + ':' + this.mongooseCredentials.passwd + this.mongooseCredentials.url)
}

API.prototype.mongoClose = function() {
  mongoose.disconnect()
  this.mongodb = null
}

API.prototype.setMongooseCredentials = function(object) {
  if(object.user === 'undefined' || object.user == null) throw 'You must define the \'USER\' of the connection!'
  else if(object.url === 'undefined' || object.url == null) throw 'You must define the \'URL\' of the connection!'
  else if(object.passwd === 'undefined' || object.passwd == null) throw 'You must define the \'PASSWORD\' of the connection!'
  else { this.mongooseCredentials = object }
}

API.prototype.closeMongooseCredentials = function(object) {
  this.mongooseCredentials = null
}

API.prototype.createSchema = function(database, object) {
  if(this.mongodb == null) throw 'Please set a connection with mongoConnect function!'
  else this.openSchema = this.mongodb.model(database, new mongoose.Schema(object))
}

API.prototype.closeSchema = function() {
  this.schema = null
}

API.prototype.addFunction = function(defs, rFunction) {
  if(rFunction instanceof Function) {
    this[defs.name] = function() {
      this.queue = new Queue(arguments)
      this.queue.setMasterFunction(rFunction)
      this.queue.next()
    }
  }
  else new Error('The second parameter must be a function!')
}

module.exports = API
